You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@maven.apache.org by ol...@apache.org on 2013/01/25 00:47:51 UTC

svn commit: r1438269 - in /maven/doxia/doxia/trunk: doxia-core/src/main/java/org/apache/maven/doxia/macro/ doxia-core/src/main/java/org/apache/maven/doxia/util/ doxia-core/src/test/java/org/apache/maven/doxia/sink/ doxia-core/src/test/java/org/apache/m...

Author: olamy
Date: Thu Jan 24 23:47:50 2013
New Revision: 1438269

URL: http://svn.apache.org/viewvc?rev=1438269&view=rev
Log:
prefer StringBuilder to StringBuffer when possible

Modified:
    maven/doxia/doxia/trunk/doxia-core/src/main/java/org/apache/maven/doxia/macro/SwfMacro.java
    maven/doxia/doxia/trunk/doxia-core/src/main/java/org/apache/maven/doxia/util/LineBreaker.java
    maven/doxia/doxia/trunk/doxia-core/src/test/java/org/apache/maven/doxia/sink/AbstractXmlSinkTest.java
    maven/doxia/doxia/trunk/doxia-core/src/test/java/org/apache/maven/doxia/xsd/AbstractXmlValidator.java
    maven/doxia/doxia/trunk/doxia-logging-api/src/main/java/org/apache/maven/doxia/logging/Log.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptParser.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptSink.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptUtils.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-apt/src/test/java/org/apache/maven/doxia/module/apt/AptSinkTest.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/ChildBlocksBuilder.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/DefinitionListBlockParser.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/FigureBlockParser.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/ParagraphBlockParser.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/VerbatimBlockParser.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/list/ListBlockParser.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/list/TreeComponent.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-docbook-simple/src/main/java/org/apache/maven/doxia/module/docbook/DocBookSink.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-fml/src/main/java/org/apache/maven/doxia/module/fml/FmlParser.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-fo/src/main/java/org/apache/maven/doxia/module/fo/FoConfiguration.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-fo/src/main/java/org/apache/maven/doxia/module/fo/FoSink.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-fo/src/test/java/org/apache/maven/doxia/module/fo/FoSinkTest.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-itext/src/main/java/org/apache/maven/doxia/module/itext/ITextFont.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-itext/src/main/java/org/apache/maven/doxia/module/itext/ITextHeader.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-itext/src/main/java/org/apache/maven/doxia/module/itext/ITextSink.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-latex/src/main/java/org/apache/maven/doxia/module/latex/LatexSink.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-rtf/src/main/java/org/apache/maven/doxia/module/rtf/AlphaNumerals.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-rtf/src/main/java/org/apache/maven/doxia/module/rtf/FontMetrics.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-rtf/src/main/java/org/apache/maven/doxia/module/rtf/PBMReader.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-rtf/src/main/java/org/apache/maven/doxia/module/rtf/RomanNumerals.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-rtf/src/main/java/org/apache/maven/doxia/module/rtf/RtfSink.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-twiki/src/main/java/org/apache/maven/doxia/module/twiki/TWikiSink.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-twiki/src/main/java/org/apache/maven/doxia/module/twiki/parser/GenericListBlockParser.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-twiki/src/main/java/org/apache/maven/doxia/module/twiki/parser/ParagraphBlockParser.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-twiki/src/main/java/org/apache/maven/doxia/module/twiki/parser/SectionBlock.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-twiki/src/main/java/org/apache/maven/doxia/module/twiki/parser/TextParser.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-xdoc/src/test/java/org/apache/maven/doxia/module/xdoc/XdocIdentityTest.java
    maven/doxia/doxia/trunk/doxia-modules/doxia-module-xhtml/src/test/java/org/apache/maven/doxia/module/xhtml/XhtmlIdentityTest.java

Modified: maven/doxia/doxia/trunk/doxia-core/src/main/java/org/apache/maven/doxia/macro/SwfMacro.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-core/src/main/java/org/apache/maven/doxia/macro/SwfMacro.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-core/src/main/java/org/apache/maven/doxia/macro/SwfMacro.java (original)
+++ maven/doxia/doxia/trunk/doxia-core/src/main/java/org/apache/maven/doxia/macro/SwfMacro.java Thu Jan 24 23:47:50 2013
@@ -142,7 +142,7 @@ public class SwfMacro
             }
         }
 
-        StringBuffer content = new StringBuffer();
+        StringBuilder content = new StringBuilder();
         content.append( "<center>" ).append( EOL );
         content.append( "<object classid=\"clsid:D27CDB6E-AE6D-11cf-96B8-444553540000\" " )
             .append( "codebase=\"http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=" )

Modified: maven/doxia/doxia/trunk/doxia-core/src/main/java/org/apache/maven/doxia/util/LineBreaker.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-core/src/main/java/org/apache/maven/doxia/util/LineBreaker.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-core/src/test/java/org/apache/maven/doxia/sink/AbstractXmlSinkTest.java (original)
+++ maven/doxia/doxia/trunk/doxia-core/src/test/java/org/apache/maven/doxia/sink/AbstractXmlSinkTest.java Thu Jan 24 23:47:50 2013
@@ -131,7 +131,7 @@ public class AbstractXmlSinkTest
     private class XmlTestSink
             extends AbstractXmlSink
     {
-        private final StringBuffer buffer = new StringBuffer( 0 );
+        private final StringBuilder buffer = new StringBuilder( 0 );
 
         public void reset()
         {

Modified: maven/doxia/doxia/trunk/doxia-core/src/test/java/org/apache/maven/doxia/xsd/AbstractXmlValidator.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-core/src/test/java/org/apache/maven/doxia/xsd/AbstractXmlValidator.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-core/src/test/java/org/apache/maven/doxia/xsd/AbstractXmlValidator.java (original)
+++ maven/doxia/doxia/trunk/doxia-core/src/test/java/org/apache/maven/doxia/xsd/AbstractXmlValidator.java Thu Jan 24 23:47:50 2013
@@ -271,7 +271,7 @@ public abstract class AbstractXmlValidat
         @Override
         public String toString()
         {
-            StringBuffer sb = new StringBuffer( 512 );
+            StringBuilder sb = new StringBuilder( 512 );
 
             sb.append( level ).append( EOL );
             sb.append( "  Public ID: " ).append( publicID ).append( EOL );

Modified: maven/doxia/doxia/trunk/doxia-logging-api/src/main/java/org/apache/maven/doxia/logging/Log.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-logging-api/src/main/java/org/apache/maven/doxia/logging/Log.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-logging-api/src/main/java/org/apache/maven/doxia/logging/Log.java (original)
+++ maven/doxia/doxia/trunk/doxia-logging-api/src/main/java/org/apache/maven/doxia/logging/Log.java Thu Jan 24 23:47:50 2013
@@ -25,7 +25,7 @@ package org.apache.maven.doxia.logging;
  * <br/>
  * There should be no big surprises here, although you may notice that the methods accept
  * <code>java.lang.CharSequence</code> rather than <code>java.lang.String</code>. This is provided mainly as a
- * convenience, to enable developers to pass things like <code>java.lang.StringBuffer</code> directly into the logger,
+ * convenience, to enable developers to pass things like <code>java.lang.StringBuilder</code> directly into the logger,
  * rather than formatting first by calling <code>toString()</code>.
  * <br/>
  * Based on <code>org.apache.maven.plugin.logging.Log</code>.

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptParser.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptParser.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptSink.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptSink.java Thu Jan 24 23:47:50 2013
@@ -49,7 +49,7 @@ public class AptSink
     private StringBuffer buffer;
 
     /**  A buffer that holds the table caption. */
-    private StringBuffer tableCaptionBuffer;
+    private StringBuilder tableCaptionBuffer;
 
     /**  author. */
     private String author;
@@ -157,7 +157,7 @@ public class AptSink
 
         resetBuffer();
 
-        this.tableCaptionBuffer = new StringBuffer();
+        this.tableCaptionBuffer = new StringBuilder();
         this.listNestingIndent = "";
 
         this.author = null;
@@ -178,7 +178,7 @@ public class AptSink
     }
 
     /**
-     * Reset the StringBuffer.
+     * Reset the StringBuilder.
      */
     protected void resetBuffer()
     {
@@ -190,7 +190,7 @@ public class AptSink
      */
     protected void resetTableCaptionBuffer()
     {
-        tableCaptionBuffer = new StringBuffer();
+        tableCaptionBuffer = new StringBuilder();
     }
 
     /** {@inheritDoc} */
@@ -645,7 +645,7 @@ public class AptSink
     /** Construct a table row. */
     private void buildRowLine()
     {
-        StringBuffer rLine = new StringBuffer();
+        StringBuilder rLine = new StringBuilder();
         rLine.append( TABLE_ROW_START_MARKUP );
 
         for ( int i = 0; i < cellCount; i++ )
@@ -988,7 +988,7 @@ public class AptSink
         }
 
         int length = text.length();
-        StringBuffer buffer = new StringBuffer( length );
+        StringBuilder buffer = new StringBuilder( length );
 
         for ( int i = 0; i < length; ++i )
         {

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptUtils.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptUtils.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptUtils.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptUtils.java Thu Jan 24 23:47:50 2013
@@ -121,7 +121,7 @@ public class AptUtils
     public static String linkToKey( String text )
     {
         int length = text.length();
-        StringBuffer buffer = new StringBuffer( length );
+        StringBuilder buffer = new StringBuilder( length );
 
         for ( int i = 0; i < length; ++i )
         {
@@ -162,7 +162,7 @@ public class AptUtils
         id = id.trim();
 
         int length = id.length();
-        StringBuffer buffer = new StringBuffer( length );
+        StringBuilder buffer = new StringBuilder( length );
 
         for ( int i = 0; i < length; ++i )
         {

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-apt/src/test/java/org/apache/maven/doxia/module/apt/AptSinkTest.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-apt/src/test/java/org/apache/maven/doxia/module/apt/AptSinkTest.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-apt/src/test/java/org/apache/maven/doxia/module/apt/AptSinkTest.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-apt/src/test/java/org/apache/maven/doxia/module/apt/AptSinkTest.java Thu Jan 24 23:47:50 2013
@@ -232,7 +232,7 @@ public class AptSinkTest extends Abstrac
     protected String getTextBlock( String text )
     {
         // "\\~, \\=, \\-, \\+, \\*, \\[, \\], \\<, \\>, \\{, \\}, \\\\"
-        StringBuffer sb = new StringBuffer();
+        StringBuilder sb = new StringBuilder();
         sb.append( getSpecialCharacters( AptMarkup.COMMENT ) ).append( ",_" );
         sb.append( getSpecialCharacters( Markup.EQUAL ) ).append( ",_" );
         sb.append( getSpecialCharacters( Markup.MINUS ) ).append( ",_" );

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/ChildBlocksBuilder.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/ChildBlocksBuilder.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/ChildBlocksBuilder.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/ChildBlocksBuilder.java Thu Jan 24 23:47:50 2013
@@ -43,7 +43,7 @@ public class ChildBlocksBuilder
 
     private List<Block> blocks = new ArrayList<Block>();
 
-    private StringBuffer text = new StringBuffer();
+    private StringBuilder text = new StringBuilder();
 
     private String input;
 
@@ -79,7 +79,7 @@ public class ChildBlocksBuilder
                     {
                         insideBold = false;
                         specialBlocks = getList( new BoldBlock( getChildren( text, specialBlocks ) ), specialBlocks );
-                        text = new StringBuffer();
+                        text = new StringBuilder();
                     }
                     else
                     {
@@ -93,7 +93,7 @@ public class ChildBlocksBuilder
                     {
                         insideItalic = false;
                         specialBlocks = getList( new ItalicBlock( getChildren( text, specialBlocks ) ), specialBlocks );
-                        text = new StringBuffer();
+                        text = new StringBuilder();
                     }
                     else
                     {
@@ -170,7 +170,7 @@ public class ChildBlocksBuilder
                             blocks.add( new LinkBlock( link, value ) );
                         }
 
-                        text = new StringBuffer();
+                        text = new StringBuilder();
                         insideLink = false;
                     }
 
@@ -197,7 +197,7 @@ public class ChildBlocksBuilder
                         insideMonospaced = false;
                         specialBlocks = getList( new MonospaceBlock( getChildren( text, specialBlocks ) ),
                                                  specialBlocks );
-                        text = new StringBuffer();
+                        text = new StringBuilder();
                     }
                     else
                     {
@@ -210,7 +210,7 @@ public class ChildBlocksBuilder
                         {
                             blocks.add( new TextBlock( "{" + name + "}" ) );
                         }
-                        text = new StringBuffer();
+                        text = new StringBuilder();
                     }
 
                     break;
@@ -268,7 +268,7 @@ public class ChildBlocksBuilder
         return list;
     }
 
-    private List<Block> getChildren( StringBuffer buffer, List<Block> currentBlocks )
+    private List<Block> getChildren( StringBuilder buffer, List<Block> currentBlocks )
     {
         String txt = buffer.toString().trim();
 
@@ -299,7 +299,7 @@ public class ChildBlocksBuilder
         return input.length() > i + 1 ? input.charAt( i + 1 ) : '\0';
     }
 
-    private StringBuffer addTextBlockIfNecessary( List<Block> blcks, List<Block> specialBlocks, StringBuffer txt )
+    private StringBuilder addTextBlockIfNecessary( List<Block> blcks, List<Block> specialBlocks, StringBuilder txt )
     {
         if ( txt.length() == 0 )
         {
@@ -317,7 +317,7 @@ public class ChildBlocksBuilder
             specialBlocks.add( textBlock );
         }
 
-        return new StringBuffer();
+        return new StringBuilder();
     }
 
 }

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/DefinitionListBlockParser.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/DefinitionListBlockParser.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/DefinitionListBlockParser.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/DefinitionListBlockParser.java Thu Jan 24 23:47:50 2013
@@ -45,8 +45,8 @@ public class DefinitionListBlockParser
     public Block visit( String line, ByLineSource source )
         throws ParseException
     {
-        StringBuffer text = new StringBuffer();
-        StringBuffer title = new StringBuffer();
+        StringBuilder text = new StringBuilder();
+        StringBuilder title = new StringBuilder();
 
         int index = line.indexOf( "title=" );
 
@@ -80,7 +80,7 @@ public class DefinitionListBlockParser
         return new DefinitionListBlock( title.toString(), text.toString() );
     }
 
-    private void append( StringBuffer title, String line )
+    private void append( StringBuilder title, String line )
     {
         if ( title.length() > 0 )
         {

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/FigureBlockParser.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/FigureBlockParser.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/VerbatimBlockParser.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/VerbatimBlockParser.java Thu Jan 24 23:47:50 2013
@@ -48,7 +48,7 @@ public class VerbatimBlockParser
     public Block visit( String line, ByLineSource source )
         throws ParseException
     {
-        StringBuffer text = new StringBuffer();
+        StringBuilder text = new StringBuilder();
 
         while ( ( line = source.getNextLine() ) != null )
         {

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/list/ListBlockParser.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/list/ListBlockParser.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/list/ListBlockParser.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/list/ListBlockParser.java Thu Jan 24 23:47:50 2013
@@ -56,7 +56,7 @@ public class ListBlockParser
     {
         TreeListBuilder treeListBuilder = new TreeListBuilder();
 
-        StringBuffer text = new StringBuffer();
+        StringBuilder text = new StringBuilder();
 
         do
         {
@@ -91,7 +91,7 @@ public class ListBlockParser
         return treeListBuilder.getBlock();
     }
 
-    private void addItem( TreeListBuilder treeListBuilder, StringBuffer text )
+    private void addItem( TreeListBuilder treeListBuilder, StringBuilder text )
     {
         String item = text.toString();
         int level = getLevel( item );

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/list/TreeComponent.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/list/TreeComponent.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/list/TreeComponent.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/list/TreeComponent.java Thu Jan 24 23:47:50 2013
@@ -91,7 +91,7 @@ class TreeComponent
 
     String toString( String indent )
     {
-        StringBuffer sb = new StringBuffer();
+        StringBuilder sb = new StringBuilder();
 
         if ( father != null )
         {

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-docbook-simple/src/main/java/org/apache/maven/doxia/module/docbook/DocBookSink.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-docbook-simple/src/main/java/org/apache/maven/doxia/module/docbook/DocBookSink.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-docbook-simple/src/main/java/org/apache/maven/doxia/module/docbook/DocBookSink.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-docbook-simple/src/main/java/org/apache/maven/doxia/module/docbook/DocBookSink.java Thu Jan 24 23:47:50 2013
@@ -1578,7 +1578,7 @@ public class DocBookSink
             logMessage( "modifiedComment", msg );
         }
 
-        StringBuffer buffer = new StringBuffer( comment.length() + 9 );
+        StringBuilder buffer = new StringBuilder( comment.length() + 9 );
 
         buffer.append( LESS_THAN ).append( BANG ).append( MINUS ).append( MINUS ).append( SPACE );
         buffer.append( comment );

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-fml/src/main/java/org/apache/maven/doxia/module/fml/FmlParser.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-fml/src/main/java/org/apache/maven/doxia/module/fml/FmlParser.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-fml/src/main/java/org/apache/maven/doxia/module/fml/FmlParser.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-fml/src/main/java/org/apache/maven/doxia/module/fml/FmlParser.java Thu Jan 24 23:47:50 2013
@@ -76,7 +76,7 @@ public class FmlParser
     private Faq currentFaq;
 
     /** Used to collect text events. */
-    private StringBuffer buffer;
+    private StringBuilder buffer;
 
     /** Map of warn messages with a String as key to describe the error type and a Set as value.
      * Using to reduce warn messages. */
@@ -186,7 +186,7 @@ public class FmlParser
         }
         else if ( parser.getName().equals( TITLE.toString() ) )
         {
-            buffer = new StringBuffer();
+            buffer = new StringBuilder();
 
             buffer.append( String.valueOf( LESS_THAN ) ).append( parser.getName() )
                 .append( String.valueOf( GREATER_THAN ) );
@@ -214,14 +214,14 @@ public class FmlParser
         }
         else if ( parser.getName().equals( QUESTION_TAG.toString() ) )
         {
-            buffer = new StringBuffer();
+            buffer = new StringBuilder();
 
             buffer.append( String.valueOf( LESS_THAN ) ).append( parser.getName() )
                 .append( String.valueOf( GREATER_THAN ) );
         }
         else if ( parser.getName().equals( ANSWER_TAG.toString() ) )
         {
-            buffer = new StringBuffer();
+            buffer = new StringBuilder();
 
             buffer.append( String.valueOf( LESS_THAN ) ).append( parser.getName() )
                 .append( String.valueOf( GREATER_THAN ) );
@@ -479,7 +479,7 @@ public class FmlParser
      * @param buffer not null
      * @throws MacroExecutionException if any
      */
-    private void handleMacroEnd( StringBuffer buffer )
+    private void handleMacroEnd( StringBuilder buffer )
             throws MacroExecutionException
     {
         if ( !isSecondParsing() )

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-fo/src/main/java/org/apache/maven/doxia/module/fo/FoConfiguration.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-fo/src/main/java/org/apache/maven/doxia/module/fo/FoConfiguration.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-fo/src/main/java/org/apache/maven/doxia/module/fo/FoConfiguration.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-fo/src/main/java/org/apache/maven/doxia/module/fo/FoConfiguration.java Thu Jan 24 23:47:50 2013
@@ -145,7 +145,7 @@ public class FoConfiguration
     }
 
     /**
-     * Adds an attribute to the current StringBuffer.
+     * Adds an attribute to the current StringBuilder.
      *
      * @param attributeId A unique id to identify the set of attributes.
      * This should correspond to the name of an attribute-set

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-fo/src/main/java/org/apache/maven/doxia/module/fo/FoSink.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-fo/src/main/java/org/apache/maven/doxia/module/fo/FoSink.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-fo/src/main/java/org/apache/maven/doxia/module/fo/FoSink.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-fo/src/main/java/org/apache/maven/doxia/module/fo/FoSink.java Thu Jan 24 23:47:50 2013
@@ -484,7 +484,7 @@ public class FoSink
      */
     private void onSectionTitle( int depth )
     {
-        StringBuffer title = new StringBuffer( 16 );
+        StringBuilder title = new StringBuilder( 16 );
 
         title.append( getChapterString() );
 
@@ -936,7 +936,7 @@ public class FoSink
     {
         String content = this.tableContentWriterStack.removeLast().toString();
 
-        StringBuffer sb = new StringBuffer();
+        StringBuilder sb = new StringBuilder();
         int cellCount = Integer.parseInt( this.cellCountStack.removeLast().toString() );
         for ( int i = 0; i < cellCount; i++ )
         {
@@ -1383,7 +1383,7 @@ public class FoSink
             logMessage( "modifyComment", msg );
         }
 
-        StringBuffer buf = new StringBuffer( comment.length() + 9 );
+        StringBuilder buf = new StringBuilder( comment.length() + 9 );
 
         buf.append( LESS_THAN ).append( BANG ).append( MINUS ).append( MINUS ).append( SPACE );
         buf.append( comment );
@@ -1598,7 +1598,7 @@ public class FoSink
     public static String escaped( String text, boolean verb )
     {
         int length = text.length();
-        StringBuffer buffer = new StringBuffer( length );
+        StringBuilder buffer = new StringBuilder( length );
 
         for ( int i = 0; i < length; ++i )
         {

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-fo/src/test/java/org/apache/maven/doxia/module/fo/FoSinkTest.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-fo/src/test/java/org/apache/maven/doxia/module/fo/FoSinkTest.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-fo/src/test/java/org/apache/maven/doxia/module/fo/FoSinkTest.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-fo/src/test/java/org/apache/maven/doxia/module/fo/FoSinkTest.java Thu Jan 24 23:47:50 2013
@@ -436,7 +436,7 @@ public class FoSinkTest
     public void testTableCaption()
         throws Exception
     {
-        StringBuffer html = new StringBuffer();
+        StringBuilder html = new StringBuilder();
         html.append( "<table>" ).append( EOL );
         html.append( "<caption>caption table</caption>" ).append( EOL );
         html.append( "<tr>" ).append( EOL );
@@ -472,7 +472,7 @@ public class FoSinkTest
     public void testNestedTables()
         throws Exception
     {
-        StringBuffer html = new StringBuffer();
+        StringBuilder html = new StringBuilder();
         html.append( "<table>" ).append( EOL );
         html.append( "<caption>first caption</caption>" ).append( EOL );
         html.append( "<tr>" ).append( EOL );

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-itext/src/main/java/org/apache/maven/doxia/module/itext/ITextFont.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-itext/src/main/java/org/apache/maven/doxia/module/itext/ITextFont.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-itext/src/main/java/org/apache/maven/doxia/module/itext/ITextFont.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-itext/src/main/java/org/apache/maven/doxia/module/itext/ITextFont.java Thu Jan 24 23:47:50 2013
@@ -200,7 +200,7 @@ public class ITextFont
     public String getFontStyle()
     {
         Font font = getCurrentFont();
-        StringBuffer sb = new StringBuffer();
+        StringBuilder sb = new StringBuilder();
 
         if ( font.isBold() )
         {

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-itext/src/main/java/org/apache/maven/doxia/module/itext/ITextHeader.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-itext/src/main/java/org/apache/maven/doxia/module/itext/ITextHeader.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-itext/src/main/java/org/apache/maven/doxia/module/itext/ITextHeader.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-itext/src/main/java/org/apache/maven/doxia/module/itext/ITextHeader.java Thu Jan 24 23:47:50 2013
@@ -34,7 +34,7 @@ public class ITextHeader
 {
     private String title;
 
-    private StringBuffer authors;
+    private StringBuilder authors;
 
     private Date date;
 
@@ -80,7 +80,7 @@ public class ITextHeader
     {
         if ( this.authors == null )
         {
-            this.authors = new StringBuffer();
+            this.authors = new StringBuilder();
         }
         else
         {

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-itext/src/main/java/org/apache/maven/doxia/module/itext/ITextSink.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-itext/src/main/java/org/apache/maven/doxia/module/itext/ITextSink.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-itext/src/main/java/org/apache/maven/doxia/module/itext/ITextSink.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-itext/src/main/java/org/apache/maven/doxia/module/itext/ITextSink.java Thu Jan 24 23:47:50 2013
@@ -1707,7 +1707,7 @@ public class ITextSink
             aString = StringUtils.replace( aString, "\n", "" );
 
             LineNumberReader lnr = new LineNumberReader( new StringReader( aString ) );
-            StringBuffer sb = new StringBuffer();
+            StringBuilder sb = new StringBuilder();
             String line;
             try
             {
@@ -1761,7 +1761,7 @@ public class ITextSink
     private static String beautifyPhrase( String aString )
     {
         String[] strings = StringUtils.split( aString, " " );
-        StringBuffer sb = new StringBuffer();
+        StringBuilder sb = new StringBuilder();
         for ( int i = 0; i < strings.length; i++ )
         {
             if ( strings[i].trim().length() != 0 )

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-latex/src/main/java/org/apache/maven/doxia/module/latex/LatexSink.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-latex/src/main/java/org/apache/maven/doxia/module/latex/LatexSink.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-latex/src/main/java/org/apache/maven/doxia/module/latex/LatexSink.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-latex/src/main/java/org/apache/maven/doxia/module/latex/LatexSink.java Thu Jan 24 23:47:50 2013
@@ -791,7 +791,7 @@ public class LatexSink
     public void tableRows( int[] justification, boolean grid )
 
     {
-        StringBuffer justif = new StringBuffer();
+        StringBuilder justif = new StringBuilder();
         for ( int i = 0; i < justification.length; ++i )
         {
             if ( grid )
@@ -1294,7 +1294,7 @@ public class LatexSink
     public static String escaped( String text )
     {
         int length = text.length();
-        StringBuffer buffer = new StringBuffer( length );
+        StringBuilder buffer = new StringBuilder( length );
 
         for ( int i = 0; i < length; ++i )
         {

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-rtf/src/main/java/org/apache/maven/doxia/module/rtf/AlphaNumerals.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-rtf/src/main/java/org/apache/maven/doxia/module/rtf/AlphaNumerals.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-rtf/src/main/java/org/apache/maven/doxia/module/rtf/AlphaNumerals.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-rtf/src/main/java/org/apache/maven/doxia/module/rtf/AlphaNumerals.java Thu Jan 24 23:47:50 2013
@@ -31,7 +31,7 @@ class AlphaNumerals
 
     static String toString( int n, boolean lowerCase )
     {
-        StringBuffer alpha = new StringBuffer();
+        StringBuilder alpha = new StringBuilder();
         char zeroLetter = lowerCase ? '`' : '@';
 
         while ( n > 0 )

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-rtf/src/main/java/org/apache/maven/doxia/module/rtf/FontMetrics.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-rtf/src/main/java/org/apache/maven/doxia/module/rtf/FontMetrics.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-rtf/src/main/java/org/apache/maven/doxia/module/rtf/FontMetrics.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-rtf/src/main/java/org/apache/maven/doxia/module/rtf/FontMetrics.java Thu Jan 24 23:47:50 2013
@@ -49,7 +49,7 @@ class FontMetrics
         String s = FontMetrics.class.getName();
         String packageName = s.substring( 0, s.lastIndexOf( '.' ) );
 
-        StringBuffer buf = new StringBuffer( packageName + "." );
+        StringBuilder buf = new StringBuilder( packageName + "." );
 
         switch ( style )
         {

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-rtf/src/main/java/org/apache/maven/doxia/module/rtf/PBMReader.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-rtf/src/main/java/org/apache/maven/doxia/module/rtf/PBMReader.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-rtf/src/main/java/org/apache/maven/doxia/module/rtf/PBMReader.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-rtf/src/main/java/org/apache/maven/doxia/module/rtf/PBMReader.java Thu Jan 24 23:47:50 2013
@@ -245,7 +245,7 @@ class PBMReader
             throws IOException
         {
             char c;
-            StringBuffer field = new StringBuffer();
+            StringBuilder field = new StringBuilder();
 
             try
             {

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-rtf/src/main/java/org/apache/maven/doxia/module/rtf/RomanNumerals.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-rtf/src/main/java/org/apache/maven/doxia/module/rtf/RomanNumerals.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-rtf/src/main/java/org/apache/maven/doxia/module/rtf/RomanNumerals.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-rtf/src/main/java/org/apache/maven/doxia/module/rtf/RomanNumerals.java Thu Jan 24 23:47:50 2013
@@ -41,7 +41,7 @@ class RomanNumerals
 
     static String toString( int n, boolean lowerCase )
     {
-        StringBuffer roman = new StringBuffer();
+        StringBuilder roman = new StringBuilder();
         String[] letters = lowerCase ? LOWER_CASE_LETTERS : UPPER_CASE_LETTERS;
 
         for ( int i = 0; i < NUMBERS.length; ++i )

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-rtf/src/main/java/org/apache/maven/doxia/module/rtf/RtfSink.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-rtf/src/main/java/org/apache/maven/doxia/module/rtf/RtfSink.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-rtf/src/main/java/org/apache/maven/doxia/module/rtf/RtfSink.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-rtf/src/main/java/org/apache/maven/doxia/module/rtf/RtfSink.java Thu Jan 24 23:47:50 2013
@@ -199,7 +199,7 @@ public class RtfSink
 
     private boolean emptyHeader;
 
-    private StringBuffer verbatim;
+    private StringBuilder verbatim;
 
     private boolean frame;
 
@@ -753,7 +753,7 @@ public class RtfSink
     {
         int nmb = ( (Integer) this.numbering.lastElement() ).intValue();
         int iNmb = ( (Counter) this.itemNumber.lastElement() ).get();
-        StringBuffer buf = new StringBuffer();
+        StringBuilder buf = new StringBuilder();
 
         switch ( nmb )
         {
@@ -1119,7 +1119,7 @@ public class RtfSink
     /** {@inheritDoc} */
     public void verbatim( boolean boxed )
     {
-        verbatim = new StringBuffer();
+        verbatim = new StringBuilder();
         frame = boxed;
 
         context.set( CONTEXT_VERBATIM );
@@ -1606,7 +1606,7 @@ public class RtfSink
     private static String normalize( String s )
     {
         int length = s.length();
-        StringBuffer buffer = new StringBuffer( length );
+        StringBuilder buffer = new StringBuilder( length );
 
         for ( int i = 0; i < length; ++i )
         {
@@ -1632,7 +1632,7 @@ public class RtfSink
     private static String escape( String s )
     {
         int length = s.length();
-        StringBuffer buffer = new StringBuffer( length );
+        StringBuilder buffer = new StringBuilder( length );
 
         for ( int i = 0; i < length; ++i )
         {
@@ -1667,7 +1667,7 @@ public class RtfSink
     {
         Font font = null;
 
-        StringBuffer buf = new StringBuffer();
+        StringBuilder buf = new StringBuilder();
         buf.append( style );
         buf.append( size );
         String key = buf.toString();

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-twiki/src/main/java/org/apache/maven/doxia/module/twiki/TWikiSink.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-twiki/src/main/java/org/apache/maven/doxia/module/twiki/TWikiSink.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-twiki/src/main/java/org/apache/maven/doxia/module/twiki/TWikiSink.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-twiki/src/main/java/org/apache/maven/doxia/module/twiki/TWikiSink.java Thu Jan 24 23:47:50 2013
@@ -1196,7 +1196,7 @@ public class TWikiSink
             throw new IllegalArgumentException( "A tag is required" );
         }
 
-        StringBuffer sb = new StringBuffer();
+        StringBuilder sb = new StringBuilder();
         sb.append( LESS_THAN );
 
         sb.append( t.toString() );
@@ -1247,7 +1247,7 @@ public class TWikiSink
      */
     private void writeEndTag( Tag t )
     {
-        StringBuffer sb = new StringBuffer();
+        StringBuilder sb = new StringBuilder();
         sb.append( LESS_THAN );
         sb.append( SLASH );
 

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-twiki/src/main/java/org/apache/maven/doxia/module/twiki/parser/GenericListBlockParser.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-twiki/src/main/java/org/apache/maven/doxia/module/twiki/parser/GenericListBlockParser.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-twiki/src/main/java/org/apache/maven/doxia/module/twiki/parser/GenericListBlockParser.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-twiki/src/main/java/org/apache/maven/doxia/module/twiki/parser/GenericListBlockParser.java Thu Jan 24 23:47:50 2013
@@ -503,7 +503,7 @@ class TreeListBuilder
         /** {@inheritDoc} */
         public String toString( final String indent )
         {
-            final StringBuffer sb = new StringBuffer();
+            final StringBuilder sb = new StringBuilder();
 
             if ( father != null )
             {

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-twiki/src/main/java/org/apache/maven/doxia/module/twiki/parser/ParagraphBlockParser.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-twiki/src/main/java/org/apache/maven/doxia/module/twiki/parser/ParagraphBlockParser.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-twiki/src/main/java/org/apache/maven/doxia/module/twiki/parser/ParagraphBlockParser.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-twiki/src/main/java/org/apache/maven/doxia/module/twiki/parser/ParagraphBlockParser.java Thu Jan 24 23:47:50 2013
@@ -89,7 +89,7 @@ public class ParagraphBlockParser
     public final Block visit( final String line, final ByLineSource source )
         throws ParseException
     {
-        StringBuffer sb = new StringBuffer();
+        StringBuilder sb = new StringBuilder();
         List<Block> childs = new ArrayList<Block>();
 
         boolean sawText = false;
@@ -121,7 +121,7 @@ public class ParagraphBlockParser
                     if ( sb.length() != 0 )
                     {
                         childs.addAll( Arrays.asList( textParser.parse( sb.toString().trim() ) ) );
-                        sb = new StringBuffer();
+                        sb = new StringBuilder();
                     }
                     childs.add( listParser.visit( l, source ) );
                 }
@@ -165,7 +165,7 @@ public class ParagraphBlockParser
         if ( sb.length() != 0 )
         {
             childs.addAll( Arrays.asList( textParser.parse( sb.toString().trim() ) ) );
-            sb = new StringBuffer();
+            sb = new StringBuilder();
         }
 
         if ( childs.size() == 0 )

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-twiki/src/main/java/org/apache/maven/doxia/module/twiki/parser/SectionBlock.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-twiki/src/main/java/org/apache/maven/doxia/module/twiki/parser/SectionBlock.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-twiki/src/main/java/org/apache/maven/doxia/module/twiki/parser/SectionBlock.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-twiki/src/main/java/org/apache/maven/doxia/module/twiki/parser/SectionBlock.java Thu Jan 24 23:47:50 2013
@@ -145,7 +145,7 @@ public class SectionBlock
     /** {@inheritDoc} */
     public final String toString()
     {
-        final StringBuffer sb = new StringBuffer();
+        final StringBuilder sb = new StringBuilder();
 
         sb.append( "Section  {title: '" );
         sb.append( getTitle() );

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-twiki/src/main/java/org/apache/maven/doxia/module/twiki/parser/TextParser.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-twiki/src/main/java/org/apache/maven/doxia/module/twiki/parser/TextParser.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-twiki/src/main/java/org/apache/maven/doxia/module/twiki/parser/TextParser.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-twiki/src/main/java/org/apache/maven/doxia/module/twiki/parser/TextParser.java Thu Jan 24 23:47:50 2013
@@ -269,7 +269,7 @@ public class TextParser
         }
 
         final StringTokenizer tokenizer = new StringTokenizer( link );
-        final StringBuffer sb = new StringBuffer();
+        final StringBuilder sb = new StringBuilder();
 
         while ( tokenizer.hasMoreElements() )
         {

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-xdoc/src/test/java/org/apache/maven/doxia/module/xdoc/XdocIdentityTest.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-xdoc/src/test/java/org/apache/maven/doxia/module/xdoc/XdocIdentityTest.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-xdoc/src/test/java/org/apache/maven/doxia/module/xdoc/XdocIdentityTest.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-xdoc/src/test/java/org/apache/maven/doxia/module/xdoc/XdocIdentityTest.java Thu Jan 24 23:47:50 2013
@@ -73,7 +73,7 @@ public class XdocIdentityTest
         int iStartTableRows =
             expected.substring( 0, iStartCaption ).lastIndexOf( "begin:tableRows" ) + "begin:tableRows".length();
 
-        StringBuffer text = new StringBuffer();
+        StringBuilder text = new StringBuilder();
         text.append( expected.substring( 0, iStartTableRows ) );
         text.append( EOL + EOL + EOL );
         text.append( captionTag.subSequence( 0, captionTag.indexOf( "end:tableCaption" )

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-xhtml/src/test/java/org/apache/maven/doxia/module/xhtml/XhtmlIdentityTest.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-xhtml/src/test/java/org/apache/maven/doxia/module/xhtml/XhtmlIdentityTest.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-xhtml/src/test/java/org/apache/maven/doxia/module/xhtml/XhtmlIdentityTest.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-xhtml/src/test/java/org/apache/maven/doxia/module/xhtml/XhtmlIdentityTest.java Thu Jan 24 23:47:50 2013
@@ -73,7 +73,7 @@ public class XhtmlIdentityTest
         int iStartTableRows =
             expected.substring( 0, iStartCaption ).lastIndexOf( "begin:tableRows" ) + "begin:tableRows".length();
 
-        StringBuffer text = new StringBuffer();
+        StringBuilder text = new StringBuilder();
         text.append( expected.substring( 0, iStartTableRows ) );
         text.append( EOL + EOL + EOL );
         text.append( captionTag.subSequence( 0, captionTag.indexOf( "end:tableCaption" )
--- maven/doxia/doxia/trunk/doxia-core/src/main/java/org/apache/maven/doxia/util/LineBreaker.java (original)
+++ maven/doxia/doxia/trunk/doxia-core/src/main/java/org/apache/maven/doxia/util/LineBreaker.java Thu Jan 24 23:47:50 2013
@@ -51,7 +51,7 @@ public class LineBreaker
     private int lineLength = 0;
 
     /** The string buffer to store the current text. */
-    private StringBuffer word = new StringBuffer( 1024 );
+    private StringBuilder word = new StringBuilder( 1024 );
 
     /**
      * Constructs a new LineBreaker with DEFAULT_MAX_LINE_LENGTH.
@@ -158,7 +158,7 @@ public class LineBreaker
     }
 
     /**
      * Write out the current StringBuffer and flush the writer.
      * Any IOException will be swallowed.
      */
     public void flush()
@@ -175,7 +175,7 @@ public class LineBreaker
     }
 
     /**
      * Writes the current StringBuffer to the writer.
      *
      * @throws IOException if an exception occurs during writing.
      */
@@ -158,7 +158,7 @@ public class LineBreaker
 
     /**
-     * Write out the current StringBuffer and flush the writer.
+     * Write out the current StringBuilder and flush the writer.
      * Any IOException will be swallowed.
      */
@@ -175,7 +175,7 @@ public class LineBreaker
 
     /**
-     * Writes the current StringBuffer to the writer.
+     * Writes the current StringBuilder to the writer.
      *
      * @throws IOException if an exception occurs during writing.

Modified: maven/doxia/doxia/trunk/doxia-core/src/test/java/org/apache/maven/doxia/sink/AbstractXmlSinkTest.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-core/src/test/java/org/apache/maven/doxia/sink/AbstractXmlSinkTest.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptParser.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptParser.java Thu Jan 24 23:47:50 2013
@@ -297,7 +297,7 @@ public class AptParser
         boolean italic = false;
         boolean bold = false;
         boolean monospaced = false;
-        StringBuffer buffer = new StringBuffer( end - begin );
+        StringBuilder buffer = new StringBuilder( end - begin );
 
         for ( int i = begin; i < end; ++i )
         {
@@ -449,7 +449,7 @@ public class AptParser
                             if ( i + 1 < end && text.charAt( i + 1 ) == LEFT_CURLY_BRACKET /*}*/ )
                             {
                                 ++i;
-                                StringBuffer buf = new StringBuffer();
+                                StringBuilder buf = new StringBuilder();
                                 i = skipTraversedLinkAnchor( text, i + 1, end, buf );
                                 linkAnchor = buf.toString();
                             }
@@ -680,7 +680,7 @@ public class AptParser
      */
     protected static String replaceAll( String string, String oldSub, String newSub )
     {
-        StringBuffer replaced = new StringBuffer();
+        StringBuilder replaced = new StringBuilder();
         int oldSubLength = oldSub.length();
         int begin, end;
 
@@ -1427,10 +1427,10 @@ public class AptParser
     /**
      * Emits the text so far parsed into the given sink.
      *
      * @param buffer A StringBuffer that contains the text to be flushed.
      * @param sink The sink to receive the text.
      */
-    private static void flushTraversed( StringBuffer buffer, Sink sink )
+    private static void flushTraversed( StringBuilder buffer, Sink sink )
     {
         if ( buffer.length() > 0 )
         {
@@ -1445,11 +1445,11 @@ public class AptParser
      * @param text the text to parse.
      * @param begin offset.
      * @param end offset.
-     * @param linkAnchor a StringBuffer.
+     * @param linkAnchor a StringBuilder.
      * @return int
      * @throws AptParseException if something goes wrong.
      */
-    private static int skipTraversedLinkAnchor( String text, int begin, int end, StringBuffer linkAnchor )
+    private static int skipTraversedLinkAnchor( String text, int begin, int end, StringBuilder linkAnchor )
         throws AptParseException
     {
         int i;
@@ -1563,7 +1563,7 @@ public class AptParser
     private String doGetTraversedLink( String text, int begin, int end )
         throws AptParseException
     {
-        final StringBuffer buffer = new StringBuffer( end - begin );
+        final StringBuilder buffer = new StringBuilder( end - begin );
 
         Sink linkSink = new SinkAdapter()
         {
@@ -1696,7 +1696,7 @@ public class AptParser
             else
             {
                 // Read block ---
-                StringBuffer buffer = new StringBuffer( firstLine );
+                StringBuilder buffer = new StringBuilder( firstLine );
 
                 while ( AptParser.this.line != null )
                 {
@@ -2251,7 +2251,7 @@ public class AptParser
 
             // Read block (first line already skipped) ---
 
-            StringBuffer buffer = new StringBuffer();
+            StringBuilder buffer = new StringBuilder();
             char firstChar = firstLine.charAt( 0 );
             boxed = ( firstChar == PLUS );
 
@@ -2386,7 +2386,7 @@ public class AptParser
             int[] justification = null;
             int rows = 0;
             int columns = 0;
-            StringBuffer[] cells = null;
+            StringBuilder[] cells = null;
             boolean[] headers = null;
             boolean grid;
 
@@ -2422,11 +2422,11 @@ public class AptParser
                         init = 1;
                         justification = parseJustification( line, lineLength );
                         columns = justification.length;
-                        cells = new StringBuffer[columns];
+                        cells = new StringBuilder[columns];
                         headers = new boolean[columns];
                         for ( i = 0; i < columns; ++i )
                         {
-                            cells[i] = new StringBuffer();
+                            cells[i] = new StringBuilder();
                             headers[i] = false;
                         }
                     }
@@ -2488,7 +2488,7 @@ public class AptParser
                         cellLine = replaceAll( cellLine, "\\u00A0\\u00A0", "\\\\" );
                         cellLine = cellLine.trim();
 
-                        StringBuffer cell = cells[i];
+                        StringBuilder cell = cells[i];
                         if ( cellLine.length() > 0 )
                         {
                             // line break in table cells
@@ -2596,7 +2596,7 @@ public class AptParser
          * @return boolean
          * @throws AptParseException if something goes wrong.
          */
-        private boolean traverseRow( StringBuffer[] cells, boolean[] headers, int[] justification )
+        private boolean traverseRow( StringBuilder[] cells, boolean[] headers, int[] justification )
             throws AptParseException
         {
             // Skip empty row (a decorative line).
@@ -2615,7 +2615,7 @@ public class AptParser
                 AptParser.this.sink.tableRow();
                 for ( int i = 0; i < cells.length; ++i )
                 {
-                    StringBuffer cell = cells[i];
+                    StringBuilder cell = cells[i];
 
                     SinkEventAttributes justif;
                     switch ( justification[i] )
@@ -1427,10 +1427,10 @@ public class AptParser
      * Emits the text so far parsed into the given sink.
      *
-     * @param buffer A StringBuffer that contains the text to be flushed.
+     * @param buffer A StringBuilder that contains the text to be flushed.
      * @param sink The sink to receive the text.
      */

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptSink.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-apt/src/main/java/org/apache/maven/doxia/module/apt/AptSink.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/FigureBlockParser.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/FigureBlockParser.java Thu Jan 24 23:47:50 2013
@@ -67,17 +67,17 @@ public class FigureBlockParser
     }
 
     /**
      * Slurp lines from the source starting with the given line appending them together into a StringBuffer until an
      * empty line is reached, and while the source contains more lines.
      *
      * @param source the source to read new lines from
      * @return a StringBuffer appended with lines
      * @throws ParseException
      */
     private String appendUntilEmptyLine( ByLineSource source )
         throws ParseException
     {
-        StringBuffer text = new StringBuffer();
+        StringBuilder text = new StringBuilder();
 
         String line;
 
@@ -67,17 +67,17 @@ public class FigureBlockParser
 
     /**
-     * Slurp lines from the source starting with the given line appending them together into a StringBuffer until an
+     * Slurp lines from the source starting with the given line appending them together into a StringBuilder until an
      * empty line is reached, and while the source contains more lines.
      *
@@ -67,17 +67,17 @@ public class FigureBlockParser
      *
      * @param source the source to read new lines from
-     * @return a StringBuffer appended with lines
+     * @return a StringBuilder appended with lines
      * @throws ParseException
      */

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/ParagraphBlockParser.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/ParagraphBlockParser.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================
--- maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/ParagraphBlockParser.java (original)
+++ maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/ParagraphBlockParser.java Thu Jan 24 23:47:50 2013
@@ -83,19 +83,19 @@ public class ParagraphBlockParser
     }
 
     /**
      * Slurp lines from the source starting with the given line appending them together into a StringBuffer until an
      * empty line is reached, and while the source contains more lines. The result can be passed to the
      * {@link #getBlocks(String)} method.
      *
      * @param line the first line
      * @param source the source to read new lines from
      * @return a StringBuffer appended with lines
      * @throws ParseException
      */
     private String appendUntilEmptyLine( String line, ByLineSource source )
         throws ParseException
     {
-        StringBuffer text = new StringBuffer();
+        StringBuilder text = new StringBuilder();
 
         do
         {
@@ -83,19 +83,19 @@ public class ParagraphBlockParser
 
     /**
-     * Slurp lines from the source starting with the given line appending them together into a StringBuffer until an
+     * Slurp lines from the source starting with the given line appending them together into a StringBuilder until an
      * empty line is reached, and while the source contains more lines. The result can be passed to the
      * {@link #getBlocks(String)} method.
@@ -83,19 +83,19 @@ public class ParagraphBlockParser
      * @param line the first line
      * @param source the source to read new lines from
-     * @return a StringBuffer appended with lines
+     * @return a StringBuilder appended with lines
      * @throws ParseException
      */

Modified: maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/VerbatimBlockParser.java
URL: http://svn.apache.org/viewvc/maven/doxia/doxia/trunk/doxia-modules/doxia-module-confluence/src/main/java/org/apache/maven/doxia/module/confluence/parser/VerbatimBlockParser.java?rev=1438269&r1=1438268&r2=1438269&view=diff
==============================================================================